pub struct FrameDecoder { /* private fields */ }Available on crate feature
h2 only.Expand description
Incremental frame decoder over a growing buffer.
Implementations
Sourceimpl FrameDecoder
impl FrameDecoder
Sourcepub fn new(max_frame_size: usize) -> FrameDecoder
pub fn new(max_frame_size: usize) -> FrameDecoder
Creates a decoder enforcing the given maximum frame payload size.
Sourcepub fn max_frame_size(&self) -> usize
pub fn max_frame_size(&self) -> usize
The maximum frame payload size the peer may send.
Sourcepub fn set_max_frame_size(&mut self, max_frame_size: usize)
pub fn set_max_frame_size(&mut self, max_frame_size: usize)
Adjusts the frame-size limit after SETTINGS_MAX_FRAME_SIZE.
Sourcepub fn block_stream(&self) -> Option<u32>
pub fn block_stream(&self) -> Option<u32>
The stream with an open field block, if any.