pub struct Decoder { /* private fields */ }Available on crate feature
h2 and (crate features h2 or h3) only.Expand description
Decodes HPACK header blocks.
Implementations
Sourceimpl Decoder
impl Decoder
Sourcepub fn new(max_table_size: usize) -> Self
pub fn new(max_table_size: usize) -> Self
Creates a decoder with the given protocol maximum table size (RFC 7541 Section 4.2: 4096 by default).
Sourcepub fn queue_size_update(&mut self, size: usize)
pub fn queue_size_update(&mut self, size: usize)
Queues a protocol-level table size update (from SETTINGS) to be applied at the start of the next header block.
Sourcepub fn set_max_header_list_size(&mut self, size: usize)
pub fn set_max_header_list_size(&mut self, size: usize)
Sets the maximum size of a decoded header list. Headers blocks whose cumulative name+value octets exceed this are rejected.