pub struct UnblockedSection {
pub stream_id: u64,
pub headers: Vec<(Bytes, Bytes)>,
}Available on crate feature
h3 only.Expand description
A field section that was buffered as blocked and has since been decoded after an encoder stream update.
Fields
stream_id: u64The stream the encoded field section was received on.
headers: Vec<(Bytes, Bytes)>The decoded header list.