Http1Zerocopy

Struct Http1Zerocopy 

pub struct Http1Zerocopy<Io> { /* private fields */ }
Available on Linux and crate feature h1-zerocopy only.
An HTTP/1.x connection handler that uses emulated sendfile for zero-copy response body transmission on Linux.

Obtain an instance via Http1::zerocopy. When a response has a ZerocopyResponse extension installed (see install_zerocopy), the handler will use emulated sendfile (utilizing the Linux splice(2) syscall and Unix pipes) to stream the file from the kernel page cache to the socket, bypassing user-space copies.

For responses without that extension the behaviour is identical to the regular Http1 handler.

Only available on Linux (target_os = "linux").