pub struct OnUpgrade { /* private fields */ }Expand description
A future that resolves to an Upgraded connection once the HTTP upgrade
handshake has been completed by the server side.
Obtain an OnUpgrade by calling prepare_upgrade on an incoming
request. The future will yield Some(Upgraded) when the server has
finished writing the upgrade response, or None if the upgrade was
cancelled or the connection was closed before the handshake completed.
Example
ⓘ
if let Some(on_upgrade) = prepare_upgrade(&mut request) {
tokio::spawn(async move {
if let Some(upgraded) = on_upgrade.await {
// `upgraded` is now a raw async I/O stream
}
});
}Trait Implementations