pub struct Settings { /* private fields */ }Available on crate feature
h3 only.Expand description
A parsed SETTINGS frame payload (RFC 9114 Section 7.2.4).
Settings are kept in wire order. Reserved (grease) identifiers are dropped on decode and may be added for encoding; unknown identifiers are preserved and ignored by the driver.
Implementations